#ifndef DOWNLOADER_H
#define DOWNLOADER_H

#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QString>
#include <QObject>
#include <QList>
#include <QFile>
#include <QFileInfo>

#include "settings.h"
#include "playlistitem.h"
#include "playlistloop.h"

class ItemDownloader : public QObject
{
    Q_OBJECT

public:
    ItemDownloader(QString &uri, QString &dest, QString &etag);
    ~ItemDownloader();
    void start();

private:
    QString m_uri;
    QFile m_file;
    QFile m_etagFile;
    QNetworkRequest m_request;
    QNetworkReply *m_reply;
    QNetworkAccessManager *m_nam;

    bool inCache();

private slots:
    void onReadyRead();
    void onFinished();

signals:
    void finished();
};


class Downloader : public QObject
{
    Q_OBJECT

public:
    Downloader(PlaylistLoop *loop);
    ~Downloader();
    void start();
    bool isDone(){return m_done;}

private:
    PlaylistLoop *m_loop;
    QString m_baseUrl;
    QString m_cacheDir;
    QString m_dataDir;
    QString m_etagDir;
    bool m_done;
    ItemDownloader *m_idl;
    int m_index;

private slots:
    void downloadNext();

signals:
    void downloadDone();
};

#endif
