#ifndef SETTINGS_H
#define SETTINGS_H

#include <QObject>
#include <QStringList>
#include <QVariant>
#include <QMap>
#include <QNetworkCookie>

class Settings : public QObject
{
    Q_OBJECT

public:
    static Settings *load(bool force=false, QString basePath="/etc/xdg/webkiosk");

    void save(QString basePath = QString(), bool with_autostart = true);

    QVariant get(QString key);
    void set(QString key, QString value);
    void set(QString key, bool value);
    void set(QString key, int value);

    QString preferencesFile(QString basePath = QString());
    QString playlistFile(QString basePath = QString());
    QString regexFile(QString basePath = QString());
    QString cookiesFile(QString basePath = QString());
    QString hookDir(QString basePath = QString());
    bool autostarted() const { return m_autostarted; }
    void setAutostarted(bool autostarted) { m_autostarted = autostarted; }

    QStringList restrictions;
    QStringList playlistItems;
    QList<QNetworkCookie> cookiesList;

    void dump();

private:
    static Settings *m_settings;
    Settings(QString basePath);
    QString m_basePath;
    QMap<QString, QVariant> m_map;
    bool m_autostarted;

    void populateDefaults();
    void readAutostarted();
    void writeAutostarted();
    void removeAutostart();
    void enableScreenSaver(bool enable);
    bool writePlaylist(QString basePath = QString());
    bool writeRestrictions(QString basePath = QString());
    bool writeCookies(QString basePath = QString());
};

#endif /* SETTINGS_H */
