#!/usr/bin/python
# -*- coding: utf-8 -*-

import json
import os
import socket
import sys
import time
from urlparse import urlparse

import bottle
import requests

from settings import Settings


UDP_IP = '127.0.0.1'
UDP_PORT = 54545
BUFFER_SIZE = 1024
PAUSE = 0
NEXT = 1
GOTO = 2
SCREENSHOT = 3
RESTART = 4
TEXT = 5
LOOP = 6


def getLocalPlaylist():
    with open("/etc/xdg/webkiosk/playlist") as fd:
        list = fd.readlines()
    plist = []
    for item in list:
        if item[0] == "#":
            continue

        name = item.split(' ')[0]
        print urlparse(name).path
        if os.path.isdir(urlparse(name).path):
            flist = os.listdir(urlparse(name).path)
            flist.reverse()
            for ditem in flist:
                list.insert(list.index(item)+1, ditem)
        else:
            item = {"name": name}
            plist.append(item)
    return plist

socketclient = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
os.chdir(os.path.dirname(os.path.realpath(sys.argv[0])))
settings = Settings()

@bottle.route('/control/pause', method="POST")
def play():
    socketclient.sendto(json.dumps({"action": PAUSE}),
                             (UDP_IP, UDP_PORT))

@bottle.route('/remote/goto', method="POST")
def goto():
    data = {"index": bottle.request.forms['index'],
            "loop": bottle.request.forms["loop"]}
    socketclient.sendto(json.dumps({"action": GOTO, "data": data}),
                             (UDP_IP, UDP_PORT))

@bottle.route('/control/next', method="POST")
def next():
    socketclient.sendto(json.dumps({"action": NEXT}),
                             (UDP_IP, UDP_PORT))

@bottle.route('/remote/screenShot', method="POST")
def screenShot():
    socketclient.sendto(json.dumps({"action": SCREENSHOT}),
                             (UDP_IP, UDP_PORT))

@bottle.route('/remote/start', method='POST')
def start():
    (url, a, b) = settings.getServer()
    if bottle.request.forms['screen'] == 'local':
        settings.setLocal()
    else:
        channel = url + '/webapp/p/' + bottle.request.forms['screen']
        settings.setChannel(channel)
    socketclient.sendto(json.dumps({"action": RESTART}),
                             (UDP_IP, UDP_PORT))

@bottle.route('/res/screen')
def screen():
    if os.uname()[4].startswith("arm"):
        time.sleep(3)
    time.sleep(1)
    return bottle.static_file("/tmp/screen.png", root='/')

@bottle.route('/remote/text', method="POST")
def text():
    for form in bottle.request.forms:
        print form
        data = {"text": bottle.request.forms.get('text')}
    socketclient.sendto(json.dumps({"action": TEXT, "data": data}),
                             (UDP_IP, UDP_PORT))

@bottle.route('/static/<filepath:path>')
def server_static(filepath):
    return bottle.static_file(filepath, root='./web')

@bottle.route("/info")
def info():
    url = "local"
    invoice = "local"
    if settings.getRemote():
        (url, invoice, email) = settings.getServer()
        headers = {"Content-type":
                   "application/x-www-form-urlencoded; charset=UTF-8",
                   "Accept": "application/json"}
        url += "/webapp/api/user/" + str(invoice)
        data = {"model": json.dumps({"invoice": str(invoice),
                                     "email": email})}
        response = requests.post(url, data=data, headers=headers)
        if response.status_code != requests.codes.ok:
            invoice = "public"
    return json.dumps({"url": url, "invoice": invoice})

@bottle.route('/remote')
def remote():
    return bottle.static_file('remote.html', root='./web')

@bottle.route('/remote/channels')
def channels():
    (baseurl, invoice, password) = settings.getServer()
    headers = {"Content-type":
               "application/x-www-form-urlencoded; charset=UTF-8",
               "Accept": "application/json"}
    url = baseurl
    url += "/webapp/api/user/" + str(invoice)
    data = {"model": json.dumps({"invoice": str(invoice),
                                 "email": password})}
    response = requests.post(url, data=data, headers=headers)
    if response.status_code != requests.codes.ok:
        response = requests.get(baseurl+"/webapp/db/channels", headers=headers)
    if callable(getattr(response, "json")):
        return json.dumps(response.json())
    else:
        return json.dumps(response.json)

@bottle.route('/remote/playlist')
def playlist():
    playlist = ""
    is_remote = False
    if settings.getRemote():
        is_remote = True
        path = os.path.expanduser("~/.linutop-kiosk/playlist")
        with open(path) as fd:
            playlist = fd.read()
    else:
        playlist = getLocalPlaylist()
    reply = json.dumps({"playlist": playlist, "remote": is_remote})
    return reply

@bottle.route('/text')
def ddonly():
    return bottle.static_file("text.html", root="./web")

@bottle.route('/')
def home():
    if settings.getDirect():
        return ddonly()
    return bottle.static_file('index.html', root='./web')


if __name__ == "__main__":
    bottle.run(host='', port=8080)

